==> Dressing_1.0.1.202506181112-1144.jar: src/dressing/ui/util/PlinthCreationWindow.java <==
package dressing.ui.util;

import org.eclipse.jface.window.Window;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlAdapter;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import dressing.ui.project.SocleSettingComposite;
import gdxapp.object3d.PlinthObject;
import org.eclipse.swt.layout.FillLayout;

public class PlinthCreationWindow extends Window {
	
	
	private Shell shell;
	private Composite composite ;
	
	private PlinthObject plinthObject;

	public PlinthCreationWindow(Shell parentShell, PlinthObject object) {
		super(parentShell);
		setShellStyle(SWT.SHELL_TRIM| SWT.APPLICATION_MODAL);
		setBlockOnOpen(true);
		this.plinthObject = object;
	}
	
	/**  
	 * Create contents of the window.
	 * @return 
	 */
	protected Control createContents(Composite parent) {
		parent.setTouchEnabled(true);
		this.shell=parent.getShell();
		parent.getShell().setText("Création du scole");
		parent.setLayout(new FillLayout());
		shell.addShellListener(getShellListener());

		composite= new SocleSettingComposite(parent, SWT.FILL, plinthObject);
		
		ControlAdapter adaptor=new ControlAdapter() {

			@Override
			public void controlResized(ControlEvent e) {
				 Rectangle area2= PlinthCreationWindow.this.getShell().getClientArea();
			     composite.setBounds(area2);
			}
			
		};
		parent.addControlListener(adaptor);
		composite.addControlListener(adaptor);
		getShell().addControlListener(adaptor);
		getShell().setBounds((getShell().getParent().getSize().x-300)/2, (getShell().getParent().getSize().y-280)/2, 300, 280);
		return composite;

	}

	@Override
	public boolean close() {
		plinthObject.setRequireRefrech(true);
		return super.close();
	}
	
	



	
	
	
}

==> Dressing_1.0.1.202507101124-1159.jar: src/dressing/ui/util/PlinthCreationWindow.java <==
package dressing.ui.util;

import org.eclipse.jface.window.Window;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlAdapter;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import dressing.ui.project.SocleSettingComposite;
import gdxapp.object3d.PlinthObject;
import gdxapp.screens.room.RoomController;

import org.eclipse.swt.layout.FillLayout;

public class PlinthCreationWindow extends Window {
	
	
	private Shell shell;
	private Composite composite ;
	
	private PlinthObject plinthObject;

	public PlinthCreationWindow(Shell parentShell, PlinthObject object) {
		super(parentShell);
		setShellStyle(SWT.SHELL_TRIM| SWT.APPLICATION_MODAL);
		setBlockOnOpen(true);
		this.plinthObject = object;
	}
	
	/**  
	 * Create contents of the window.
	 * @return 
	 */
	protected Control createContents(Composite parent) {
		parent.setTouchEnabled(true);
		this.shell=parent.getShell();
		parent.getShell().setText("Création du scole");
		parent.setLayout(new FillLayout());
		shell.addShellListener(getShellListener());

		composite= new SocleSettingComposite(parent, SWT.FILL, plinthObject);
		
		ControlAdapter adaptor=new ControlAdapter() {

			@Override
			public void controlResized(ControlEvent e) {
				 Rectangle area2= PlinthCreationWindow.this.getShell().getClientArea();
			     composite.setBounds(area2);
			}
			
		};
		parent.addControlListener(adaptor);
		composite.addControlListener(adaptor);
		getShell().addControlListener(adaptor);
		getShell().setBounds((getShell().getParent().getSize().x-300)/2, (getShell().getParent().getSize().y-280)/2, 300, 280);
		return composite;

	}

	@Override
	public boolean close() {
		RoomController.getInstance().updateObject2D(plinthObject);
		plinthObject.setRequireRefrech(true);
		return super.close();
	}
	
	



	
	
	
}
